%global debug_package %{nil}
#
# spec file for package shadowsocks-rust
#

Name:           shadowsocks-rust
Version:        1.18.1
Release:        1%{?dist}
Summary:        A Rust port of shadowsocks
License:        MIT
Group:          Productivity/Networking/Web/Proxy
URL:            https://github.com/shadowsocks/shadowsocks-rust
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}-config.json
Source2:        %{name}-client.service
Source3:        %{name}-server.service
Source4:        %{name}-client@.service
Source5:        %{name}-server@.service
Conflicts:      python-shadowsocks python3-shadowsocks
Requires:       libcap

%if 0%{?suse_version}
Requires:       libopenssl1_0_0
BuildRequires:  libopenssl-devel
%else
Requires:       openssl
BuildRequires:  openssl-devel
%endif

%if 0%{?fedora} >= 15 || 0%{?rhel} >=7 || 0%{?suse_version} >= 1210
%global use_systemd 1
%else
%global use_systemd 0
%endif

%if 0%{?rhel} == 7
BuildRequires: devtoolset-9-gcc devtoolset-9-make
%else
BuildRequires: gcc make
%endif

%if 0%{?use_systemd}
%{?systemd_requires}
%if 0%{?suse_version}
BuildRequires:   systemd-rpm-macros
%else
BuildRequires:   systemd
%endif
%endif

%description
shadowsocks-rust is a rust port of lightweight secured scoks5 proxy.

%prep
%setup -q

%build
%if 0%{?rhel} == 7
%enable_devtoolset9
%endif
SODIUM_BUILD_STATIC=yes
cargo build --release --features "local-tun local-redir aead-cipher-2022-extra"

%install
make install TARGET=release PREFIX=/usr/bin DESTDIR=%{buildroot}
install -d %{buildroot}%{_sysconfdir}/shadowsocks/
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/shadowsocks/
install -d %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE3} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE4} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE5} %{buildroot}%{_unitdir}

%pre
%if 0%{?use_systemd} && 0%{?suse_version}
%service_add_pre %{name}-server.service
%endif

%post
%if ! 0%{?use_systemd}
/sbin/chkconfig --add %{name}-server > /dev/null 2>&1 || :
%else
%if 0%{?suse_version}
%service_add_post %{name}-server.service
%else
%systemd_post %{name}-server.service
%endif
%endif
setcap cap_net_bind_service+ep %{_bindir}/sslocal \
       cap_net_bind_service+ep %{_bindir}/ssserver

%preun
%if ! 0%{?use_systemd}
if [ $1 -eq 0 ]; then
    /sbin/service %{name}-server stop  > /dev/null 2>&1 || :
    /sbin/chkconfig --del %{name}-server > /dev/null 2>&1 || :
fi
%else
%if 0%{?suse_version}
%service_del_preun %{name}-server.service
%service_del_preun %{name}-client.service
%else
%systemd_preun %{name}-server.service
%systemd_preun %{name}-client.service
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    systemctl stop %{name}-server@'*'.service  > /dev/null 2>&1 || :
    systemctl stop %{name}-client@'*'.service  > /dev/null 2>&1 || :
    systemctl --no-reload disable %{name}-server@.service  > /dev/null 2>&1 || :
    systemctl --no-reload disable %{name}-client@.service  > /dev/null 2>&1 || :
fi
%endif
%endif

%postun
%if 0%{?use_systemd}
%if 0%{?suse_version}
%service_del_postun %{name}-server.service
%else
%systemd_postun_with_restart %{name}-server.service
%systemd_postun_with_restart %{name}-client.service
%systemd_postun_with_restart %{name}-server@'*'.service
%systemd_postun_with_restart %{name}-client@'*'.service
%endif
%endif

%files
%defattr(-,root,root)
%doc README.md
%dir %{_sysconfdir}/shadowsocks
%config(noreplace) %{_sysconfdir}/shadowsocks/%{name}-config.json
%license LICENSE
%{_bindir}/ss*
%{_unitdir}/%{name}-*.service

%changelog
* Mon Feb 19 2024 Teddysun <i@teddysun.com> - 1.18.1-1
- Update version to 1.18.1

* Fri Feb 09 2024 Teddysun <i@teddysun.com> - 1.18.0-1
- Update version to 1.18.0

* Fri Feb 02 2024 Teddysun <i@teddysun.com> - 1.17.2-1
- Update version to 1.17.2

* Mon Jan 15 2024 Teddysun <i@teddysun.com> - 1.17.1-2
- Enabled Optional Feature aead-cipher-2022-extra

* Mon Nov 27 2023 Teddysun <i@teddysun.com> - 1.17.1-1
- Update version to 1.17.1

* Sun Oct 15 2023 Teddysun <i@teddysun.com> - 1.17.0-1
- Update version to 1.17.0

* Sat Sep 23 2023 Teddysun <i@teddysun.com> - 1.16.2-1
- Update version to 1.16.2

* Fri Sep 01 2023 Teddysun <i@teddysun.com> - 1.16.1-1
- Update version to 1.16.1

* Sun Aug 27 2023 Teddysun <i@teddysun.com> - 1.16.0-1
- Update version to 1.16.0

* Fri Jul 07 2023 Teddysun <i@teddysun.com> - 1.15.4-1
- Update version to 1.15.4

* Mon Mar 13 2023 Teddysun <i@teddysun.com> - 1.15.3-1
- Update version to 1.15.3

* Sat Dec 24 2022 Teddysun <i@teddysun.com> - 1.15.2-1
- Update version to 1.15.2

* Sat Dec 17 2022 Teddysun <i@teddysun.com> - 1.15.1-1
- Update version to 1.15.1

* Sat Dec 17 2022 Teddysun <i@teddysun.com> - 1.15.0-1
- Update version to 1.15.0

* Mon Oct 24 2022 Teddysun <i@teddysun.com> - 1.15.0.alpha.9-1
- Update version to 1.15.0-alpha.9

* Sat Jun 18 2022 Teddysun <i@teddysun.com> - 1.14.3-1
- Update version to 1.14.3
